@@ -373,6 +373,10 @@ class ExplainerDashboard:
             ("explainer should be an instance of BaseExplainer, such as "
             "ClassifierExplainer or RegressionExplainer!")
         
+        if kwargs: 
+            print("**kwargs: Passing the following keyword arguments to all the dashboard"
+                f" ExplainerComponents: {', '.join([f'{k}={v}' for k,v in kwargs.items()])}...")
+
         if tabs is None:
             tabs = []
             if model_summary and explainer.y_missing:
@@ -383,25 +387,25 @@ class ExplainerDashboard:
                 print("For this type of model and model_output interactions don't "
                           "work, so setting shap_interaction=False...", flush=True)
                 shap_interaction = False
-            if decision_trees and not hasattr(explainer, 'decision_trees'):
-                print("the explainer object has no decision_trees property. so "
+            if decision_trees and not hasattr(explainer, 'is_tree_explainer'):
+                print("The explainer object has no decision_trees property. so "
                         "setting decision_trees=False...", flush=True)
                 decision_trees = False
         
             if importances:
-                tabs.append(ImportancesTab)
+                tabs.append(ImportancesComposite)
             if model_summary:
-                tabs.append(ModelSummaryTab)
+                tabs.append(ClassifierModelStatsComposite if explainer.is_classifier else RegressionModelStatsComposite)
             if contributions:
-                tabs.append(ContributionsTab)
+                tabs.append(IndividualPredictionsComposite)
             if whatif:
-                tabs.append(WhatIfTab)
+                tabs.append(WhatIfComposite)
             if shap_dependence:
-                tabs.append(ShapDependenceTab)
+                tabs.append(ShapDependenceComposite)
             if shap_interaction:
-                tabs.append(ShapInteractionsTab)
+                tabs.append(ShapInteractionsComposite)
             if decision_trees:
-                tabs.append(DecisionTreesTab)
+                tabs.append(DecisionTreesComposite)
 
         if isinstance(tabs, list) and len(tabs)==1:
             tabs = tabs[0]
@@ -673,37 +677,39 @@ class ExplainerDashboard:
             self.app.run_server(port=port, **kwargs)
         elif self.mode == 'external':
             if not self.is_colab:
-                print(f"Starting ExplainerDashboard on http://localhost:{port}", flush=True)
+                print(f"Starting ExplainerDashboard on http://localhost:{port}\n"
+                      f"You can terminate it with ExplainerDashboard.terminate({port})", flush=True)
             self.app.run_server(port=port, mode=self.mode, **kwargs)
         elif self.mode in ['inline', 'jupyterlab']:
+            print(f"Starting ExplainerDashboard inline (terminate it with "
+                    "ExplainerDashboard.terminate({port}))", flush=True)
             self.app.run_server(port=port, mode=self.mode, 
                                 width=self.width, height=self.height, **kwargs)
         else:
             raise ValueError(f"Unknown mode: {mode}...")
 
-    def terminate(self, port=None, token=None):
-        """terminate a JupyterDash based DashboardExplainer i.e. mode 
-        in ['inline', 'jupyterlab', 'external']
+    @classmethod
+    def terminate(cls, port, token=None):
+        """
+        Classmethodd to terminate any JupyterDash dashboard (so started with 
+        mode='inline',  mode='external' or mode='jupyterlab') from any 
+        ExplainerDashboard by specifying the right port. 
 
-        You can kill any JupyterDash dashboard from any ExplainerDashboard
-        by specifying the right port. 
+        Example:
+            ExplainerDashboard(explainer, mode='external').run(port=8050)
+
+            ExplainerDashboard.terminate(8050) 
+            db = ExplainerDashboard(explainer)
+            db.terminate(8050)
 
         Args:
-            port (int, optional): port on which the dashboard is running. 
-                        Defaults to the last port the instance had started on.
+            port (int): port on which the dashboard is running. 
             token (str, optional): JupyterDash._token class property. 
                 Defaults to the _token of the JupyterDash in the current namespace.
 
         Raises:
             ValueError: if can't find the port to terminate.
         """
-        if port is None:
-            try:
-                port = self.port
-            except:
-                raise ValueError("Can't find port to terminate. You either first "
-                        "need to run() a dashboard with this instance, or you "
-                        "need to pass a port to terminate...")
         if token is None:
             token = JupyterDash._token
         
