@@ -31,8 +31,8 @@ class ClassifierBunchTests(unittest.TestCase):
         self.explainer.pos_label = "Not survived"
         self.assertIsInstance(self.explainer.pos_label, int)
         self.assertIsInstance(self.explainer.pos_label_str, str)
-        self.assertEquals(self.explainer.pos_label, 0)
-        self.assertEquals(self.explainer.pos_label_str, "Not survived")
+        self.assertEqual(self.explainer.pos_label, 0)
+        self.assertEqual(self.explainer.pos_label_str, "Not survived")
 
     def test_get_prop_for_label(self):
         self.explainer.pos_label = 1
@@ -47,6 +47,8 @@ class ClassifierBunchTests(unittest.TestCase):
     def test_metrics(self):
         self.assertIsInstance(self.explainer.metrics(), dict)
         self.assertIsInstance(self.explainer.metrics(cutoff=0.9), dict)
+        self.assertIsInstance(self.explainer.metrics_descriptions(cutoff=0.9), dict)
+
 
     def test_precision_df(self):
         self.assertIsInstance(self.explainer.precision_df(), pd.DataFrame)
@@ -76,6 +78,12 @@ class ClassifierBunchTests(unittest.TestCase):
         fig = self.explainer.plot_cumulative_precision()
         self.assertIsInstance(fig, go.Figure)
 
+        fig = self.explainer.plot_cumulative_precision(percentile=0.5)
+        self.assertIsInstance(fig, go.Figure)
+
+        fig = self.explainer.plot_cumulative_precision(percentile=0.1, pos_label=0)
+        self.assertIsInstance(fig, go.Figure)
+
     def test_plot_confusion_matrix(self):
         fig = self.explainer.plot_confusion_matrix(normalized=False, binary=False)
         self.assertIsInstance(fig, go.Figure)
